PaginationController<Key, Value> class

State management agnostic pagination controller

Constructors

PaginationController({required PagingSource<Key, Value> pagingSource, int pageSize = 20, Key? initialKey})

Properties

currentState PaginationState<Value>
Current state snapshot
no setter
hashCode int
The hash code for this object.
no setterinherited
hasMore bool
no setter
isLoading bool
no setter
items List<Value>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateStream Stream<PaginationState<Value>>
Stream of pagination states - can be consumed by any state management solution
no setter

Methods

dispose() → void
Dispose resources
loadMore() Future<void>
Load more items
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh() Future<void>
Refresh the data
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited