PaginationState<T> class

Constructors

PaginationState({required List<T> items, required PaginationStatus status, required bool hasMore, String? error})
const

Properties

error String?
final
hashCode int
The hash code for this object.
no setteroverride
hasMore bool
final
items List<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PaginationStatus
final

Methods

copyWith({List<T>? items, PaginationStatus? status, bool? hasMore, String? error}) PaginationState<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override